#
# spec file for package ioquake3
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %{nil}
# Some arch have no VM (aarch64, ...)
%define arch_with_vm  %{ix86} x86_64 ppc ppc64 armv7l armv7hl
Name:           ioquake3
Version:        1.36+git.20231226
Release:        1.3
Summary:        Quake III
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            https://ioquake3.org
Source:         %{name}-%{version}.tar.xz
BuildRequires:  Mesa-devel
BuildRequires:  curl-devel
BuildRequires:  openal-soft-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(sdl2)
ExcludeArch:    armv6l armv6hl

%package devel
Summary:        Quake III
Group:          Development/Tools/Building

%description
Quake III first person shooter. This package only includes the binary
files, you still need the data files from the original Quake III CD or
the Demo.

%description devel
Quake III development tools for creating mods: q3lcc, q3rcc, q3cpp,
q3asm

%prep
%setup -q
rm -rf code/SDL2 code/libs code/AL

%build
cat > dobuild <<'EOF'
#!/bin/sh
%make_build \
%ifarch armv7l armv7hl
    COMPILE_ARCH=armv7l \
%endif
%ifarch aarch64
    COMPILE_ARCH=aarch64 \
%endif
	VERSION=%{version} \
	RELEASE=%{release} \
	OPTIMIZE="%{optflags} -O3 -ffast-math -fno-strict-aliasing" \
	TOOLS_OPTIMIZE="%{optflags} -fno-strict-aliasing" \
	GENERATE_DEPENDENCIES=0 \
	USE_LOCAL_HEADERS=0 \
	V=1 \
	"$@"
EOF
chmod 755 dobuild

./dobuild release

%install
arch=`uname -m`
case $arch in
	i?86) arch=x86 ;;
esac
q3dir=%{buildroot}%{_prefix}/lib/ioquake3
install -d -m 755 $q3dir
%ifarch %{arch_with_vm}
install -d -m 755 $q3dir/baseq3/vm
%else
install -d -m 755 $q3dir/baseq3
%endif
install -d -m 755 $q3dir/demoq3
%ifarch %{arch_with_vm}
install -d -m 755 $q3dir/missionpack/vm
%else
install -d -m 755 $q3dir/missionpack
%endif
pushd build/release-linux-$arch/
install -m 755 ioquake3.$arch $q3dir/
install -m 755 ioq3ded.$arch $q3dir/
install -m 644 renderer_opengl1_$arch.so $q3dir/
install -m 644 renderer_opengl2_$arch.so $q3dir/
install -m 644 baseq3/*.so $q3dir/baseq3
%ifarch %{arch_with_vm}
install -m 644 baseq3/vm/*.qvm $q3dir/baseq3/vm
%endif
pushd $q3dir/demoq3
ln -s ../baseq3/*.so .
popd
install -m 644 missionpack/*.so $q3dir/missionpack
%ifarch %{arch_with_vm}
install -m 644 missionpack/vm/*.qvm $q3dir/missionpack/vm
%endif
popd

# icons and start scripts
install -d -m 755 %{buildroot}%{_bindir}
install -d -m 755 %{buildroot}%{_datadir}/pixmaps
install -d -m 755 %{buildroot}%{_datadir}/applications
install -m 644 misc/quake3.png %{buildroot}%{_datadir}/pixmaps
install -m 644 misc/setup/ioquake3.desktop %{buildroot}%{_datadir}/applications/ioquake3.desktop
install -m 755 misc/setup/ioq3demo.sh $q3dir/
install -m 755 misc/setup/ioquake3.sh $q3dir/

for i in ioq3demo ioquake3; do
	echo -e "#!/bin/sh\nexec %{_prefix}/lib/ioquake3/$i.sh \"\$@\"" > %{buildroot}%{_bindir}/$i
	chmod 755 %{buildroot}%{_bindir}/$i
done

# devel tools
%ifarch %{arch_with_vm}
install -d -m 755 %{buildroot}%{_bindir}
install -m 755 build/release-linux-$arch/tools/q3{lcc,cpp,rcc,asm} %{buildroot}%{_bindir}
%endif

%post
echo 'copy pak[0-8].pk3 to /usr/lib/ioquake3/baseq3/'

%files
%license COPYING.txt
%doc README* id-readme.txt
%doc voip-readme.txt opengl2-readme.md
%{_bindir}/ioq*
%{_prefix}/lib/ioquake3
%{_datadir}/applications/*
%{_datadir}/pixmaps/*

%files devel
%doc code/tools/lcc/COPYRIGHT
%ifarch %{arch_with_vm}
%{_bindir}/q3*
%endif

%changelog
* Thu Dec 28 2023 lnussel@suse.com
- Update to version 1.36+git.20231226:
  * Fix building QVMs on Linux with Windows line endings
  * OpenGL2: Fix parsing q3gl2_sun without two additional tokens
  * OpenGL2: Fix q3map2 lightstyles effects
  * OpenGL2: Fix updating the loading screen with r_cubeMapping 1
  * OpenGL2: Fix FB-MSAA on AMD Windows driver
  * OpenGL2: Fix r_clear when using HDR/FB-MSAA
  * OpenGL2: Fix border for cg_viewsize using HDR/FB-MSAA w/postProcess
  * Build QVMs even if there is no QVM JIT
  * Improve AppStream metainfo
  * Update org.ioquake3.ioquake3.metainfo.xml
  * Add AppStream metadata
  * Don't list mod directories at Windows drive root
  * nsis: Only uninstall protocol handler for this installation
  * nsis: Fix CustomUrlArguments for protocol handler
  * nsis: Add better descriptions for OpenAL and libcurl
  * nsis: Display ioquake3 version
  * nsis: Require installing SDL
  * nsis: Remove Speex library
  * Fix macOS client/server failing to start from terminal
  * Update CI actions version
  * Update CI to macOS 11
  * Fix bad client reliableAcknowledge DOS exploit
  * Add protocol handler support
  * Update SECURITY.md
  * Update CI to Ubuntu 20.04
  * Document USE_INTERNAL_VORBIS in README
  * Update MSVC .lib files to SDL 2.24.0
  * Fix running make-macosx{,-ub2}.sh on Linux
  * Update macOS UB1 to SDL 2.0.22
  * Update to SDL 2.24.0 and add separate macOS UB2 dylib
  * Added .gitignore to msvc folder
  * Added .gitignore to msvc11 folder
  * Add .gitignore to msvc10 folder
  * Updated .gitgnore to latest GitHub template
  * Minor typo correction to be_aas_file.c
  * Fixed another minor typo or two
* Sun Jan 22 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.36+git.20221123:
  * Fix (disabled) Wavelet sound decompression
  * Fix in_availableJoysticks cvar not updating
  * Add keys for SDL 2.0.14's new gamepad buttons
  * More predictable mesh normals generation
  * Bugfixes
- Spec file cleaning, e.g. removed loki installer stuff
* Wed Nov  2 2022 Cristian Rodríguez <crrodriguez@opensuse.org>
- Remove nasm build requires, no longer used.
* Sat Jan 29 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.36+git.20211208
  * Fix memory corruption in S_TransferPaintBuffer
  * OpenGL2: GL_DEPTH_TEXTURE_MODE was removed from OpenGL 3.0/Core
  * Fix being unable to enter Team Arena CD key
  * Print full GL_EXTENSIONS list for OpenGL contexts before 3.0
  * OpenGL2: Fix r_grayscale 1 making everything solid black
  * qsort cannot be called with NULL
- Fix build on aarch64 (COMPILE_ARCH=aarch64)
* Sun Aug  1 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.36+git.20210720
  * Add TOOLS_CFLAGS to build preamble
  * Fix use of TOOLS_CC being reported as CC
  * Use the correct compiler for tools when cross building under
    cygwin
  * Allow using pulseaudio for SDL audio capture
  * Restore bots crushing unseen player on q3tourney6 in non-CTF
  * Fix the number of weights in the IQM model calculation
  * Fixes a crash when compiling the project on windows in
    64 bit mode
  * Allow unwinding of qvmcall64 call-stub for msvc/masm
  * Add epsilon to avoid division by zero in CalcSpecular()
  * Add r_parallaxMapOffset
  * Fix line not removed in previous commit
  * OpenGL2: Flip normals for backfacing triangles
* Sat Nov 28 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.36+git.20201117
  - Add C syntax highlighting to readme
  - Update README.md
  - Merge pull request #447 from HappyFacade/patch-1
  - Simplify glsl -> C stringification
  - Make LCC path resolution more robust
  - GitHub Actions setup
  - Remove old CI system configurations
  - Add status badge to README
  - Fix shader stringify
  - Run apt-get update before installing deps
  - Avoid platform sed differences
  - Merge pull request #436 from Calinou/default-texturemode-mipmap-linear
  - [sdl] Turn tentative definition into actual definition
* Wed Apr 29 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Handle architectures which have no VM (aarch64, ...)
- Fix build on armv7
- Exclude armv6
* Sat Apr 11 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.36+git.20200211 (list is not complete)
  - Fix loading favorites as initial source in server browser
  - Improve finding obelisk entitynum for bot AI
  - Fix SDL audio playback with surround sound
  - Fix predicting entity origin on rotating mover
  - Allow binds to use hex values for all key codes
  - Disable pulseaudio capture regardless of SDL version
  - Fix SDL audio playback with 16-bit stereo sound
  - OpenGL2: r_cubemapping 2 for box cubemap parallax
  - Add r_parallaxMapShadows
  - Restore OpenGL 1.1 support (GL_CLAMP)
  - q3rcc: Allow to override build date
  - Fix lightning gun handling for corpses and single player
    podiums
- Spec file cleaning
- Drop 0001-q3rcc-Allow-to-override-build-date.patch because it
  is included upstream (commit a96f32e)
* Thu Aug  8 2019 Martin Hauke <mardnh@gmx.de>
- Add patch in order to make builds reproducable:
  * 0001-q3rcc-Allow-to-override-build-date.patch
- Disable LTO for now (segfaults)
* Sun Aug  5 2018 mardnh@gmx.de
- Update to version 1.36+git.20180802
- Drop not longer needed patches:
  * fix-for-opensuse-x86-ioq3demo_sh.diff
  * fix-for-opensuse-x86-ioquake3_sh.diff
* Sun Jan 17 2016 kieltux@gmail.com
- Added packaging in spec of missing renderer:
  renderer_opengl1_$arch.so
  renderer_opengl2_$arch.so
- Added PATCH-FIX-OPENSUSE fix-for-opensuse-x86-ioq3demo_sh.diff
  for x86 (i386 -> x86)
- Added PATCH-FIX-OPENSUSE fix-for-opensuse-x86-ioquake3_sh.diff
  for x86 (i386 -> x86)
* Sun May 10 2015 dap.darkness@gmail.com
- Updated from git#2292bf5bb2e3178674492d4dfd46b63515d0abe1
  to resolve *64 build issue.
- Removed merged ioquake3-1.36-strcpy.diff.
* Wed Dec 26 2012 joop.boonen@opensuse.org
- openal-devel is now called openal-soft-devel
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
- Remove duplicate changelog
* Sun Jul  4 2010 lnussel@suse.de
- fix wrong use of strcpy (bio#4331)
* Sun Apr 12 2009 lnussel@suse.de
- new version 1.36
* Mon Mar  2 2009 lnussel@suse.de
- update to SVN1507 in trunk
* Sun Jan 18 2009 lnussel@suse.de
- update to SVN1493 in trunk, includes security fix
* Fri Jan 16 2009 lnussel@suse.de
- update to SVN1492 in trunk
* Mon Jan 12 2009 lnussel@suse.de
- optionally only build the installer
* Fri Jan  9 2009 lnussel@suse.de
- update to SVN1489 in trunk
* Mon Nov 10 2008 lnussel@suse.de
- update to SVN1486 in trunk
* Wed Nov  5 2008 lnussel@suse.de
- update to SVN1481 in trunk
* Fri Sep 12 2008 lnussel@suse.de
- update to SVN1470 in trunk
* Wed Sep  3 2008 lnussel@suse.de
- update to SVN1469 in trunk
* Wed Aug 20 2008 lnussel@suse.de
- update to SVN1450 in trunk
* Sat Aug  9 2008 lnussel@suse.de
- update to SVN 1443 in trunk
* Thu Jul 17 2008 lnussel@suse.de
- update to SVN 1429 in trunk
* Wed Jul 16 2008 lnussel@suse.de
- update to SVN 1427 in trunk
* Sun Jul  6 2008 lnussel@suse.de
- update to SVN 1419 in trunk
* Sun Jul  6 2008 lnussel@suse.de
- update to SVN 1413 in trunk
* Sat Jul  5 2008 lnussel@suse.de
- update to SVN 1403 in trunk
* Wed Jun 25 2008 lnussel@suse.de
- update to SVN 1398 in trunk
* Wed Jun 25 2008 lnussel@suse.de
- update to SVN 1394 in trunk
* Sun Jun  8 2008 lnussel@suse.de
- update to SVN 1382 in trunk
  * now support voice activation for voip
* Sat Jun  7 2008 lnussel@suse.de
- update to SVN 1371 in trunk
- use upstream desktop file
* Thu Jun  5 2008 lnussel@suse.de
- update to SVN 1369 in trunk
* Tue Jun  3 2008 lnussel@suse.de
- update to SVN 1363 in trunk
- includes voip support
* Sat May 31 2008 lnussel@suse.de
- update to SVN 1347 in trunk
- use dlopen for libopenal in installer build
* Wed May  7 2008 lnussel@suse.de
- update to SVN 1341 in trunk
* Sat May  3 2008 lnussel@suse.de
- update to SVN 1337 in trunk
* Mon Apr 28 2008 lnussel@suse.de
- update to SVN 1332 in trunk
  * supports stereoscopic view
* Tue Apr 22 2008 lnussel@suse.de
- update to SVN 1324 in trunk
* Tue Apr 15 2008 lnussel@suse.de
- update to SVN 1321 in trunk
* Sat Apr 12 2008 lnussel@suse.de
- update to SVN 1318 in trunk
* Thu Apr 10 2008 lnussel@suse.de
- update to SVN 1307 in trunk
* Mon Apr  7 2008 lnussel@suse.de
- update to SVN 1303 in trunk
* Sun Apr  6 2008 lnussel@suse.de
- update to SVN 1300 in trunk
* Sat Apr  5 2008 lnussel@suse.de
- update to SVN 1294 in trunk
* Sat Apr  5 2008 lnussel@suse.de
- update to SVN 1290 in trunk
  * initial ipv6 support
* Fri Mar 28 2008 lnussel@suse.de
- update to SVN 1287 in trunk
* Thu Mar 27 2008 lnussel@suse.de
- update to SVN 1286 in trunk
* Fri Mar 21 2008 lnussel@suse.de
- update to SVN 1272 in trunk
* Sun Mar  9 2008 lnussel@suse.de
- update to SVN 1270 in trunk
* Wed Jan 23 2008 lnussel@suse.de
- update to SVN 1250 in trunk
  * fixes several format string bugs
* Wed Jan  9 2008 lnussel@suse.de
- update to SVN 1248 in trunk
* Sat Dec  8 2007 lnussel@suse.de
- update to SVN 1231 in trunk
* Fri Nov 16 2007 lnussel@suse.de
- update to SVN 1212 in trunk
* Tue Oct 23 2007 lnussel@suse.de
- update to SVN 1201 in trunk
* Fri Oct  5 2007 lnussel@suse.de
- update to SVN 1189 in trunk
* Tue Sep 11 2007 lnussel@suse.de
- update to SVN 1176 in trunk
* Thu Sep  6 2007 lnussel@suse.de
- update to SVN 1166 in trunk
* Mon Aug 27 2007 lnussel@suse.de
- update to SVN 1138 in trunk
* Sun Aug 19 2007 lnussel@suse.de
- update to SVN 1126 in trunk
* Wed Jul  4 2007 lnussel@suse.de
- update to SVN 1106 in trunk
- update vm_x86_64 assembler patch
* Fri Jun 29 2007 lnussel@suse.de
- update to SVN 1103 in trunk
- add experimental vm_x86_64 assembler patch
* Fri May 11 2007 lnussel@suse.de
- update to SVN 1083 in trunk
* Tue Jan 23 2007 lnussel@suse.de
- update to SVN 1036 in trunk
- rename to ioquake3
* Fri Dec  1 2006 lnussel@suse.de
- update to SVN 996 in 1.34 branch (1.34RC3)
* Thu Oct 26 2006 lnussel@suse.de
- update to SVN 955 in 1.34 branch
  * fixes wrong use of strncat
- disable installer
* Tue Sep  5 2006 lnussel@suse.de
- update to SVN 892 (1.34RC2)
* Mon Jun  5 2006 lnussel@suse.de
- update to SVN 797
  * fixes buffer overflow in CL_ParseDownload
  * fixes ppc vm
* Mon May  8 2006 lnussel@suse.de
- update to SVN 777
  * fixes directory traversal bug (CVE-2006-2082)
* Sat May  6 2006 lnussel@suse.de
- update to SVN 772
  * fixes exploitable buffer overflow (CVE-2006-2236)
* Thu Mar  9 2006 lnussel@suse.de
- update to current SVN
  * fixes among other things SEGV on i386 without READ_IMPLIES_EXEC
* Tue Feb 21 2006 lnussel@suse.de
- update to current SVN
- add desktop file and start script
* Mon Jan 30 2006 ro@suse.de
- added Mesa-devel to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 lnussel@suse.de
- update to current SVN
  * offending EULA removed (#136922)
* Thu Dec  1 2005 lnussel@suse.de
- update to current SVN
  * quake3-setup subpackage builds installer for upstream
* Mon Nov 14 2005 lnussel@suse.de
- update to current SVN
  * with openal support
* Thu Nov  3 2005 lnussel@suse.de
- update to current SVN
* Sun Oct  9 2005 lnussel@suse.de
- update to current SVN
- add devel subpackage that contains qvm compiler and assembler
* Fri Sep  9 2005 lnussel@suse.de
- update to current SVN
  * supposed to fix soundlag
  * works on 16bit displays
* Thu Sep  1 2005 lnussel@suse.de
- update to current SVN, now with SDL sound
* Wed Aug 31 2005 lnussel@suse.de
- new package
